@@ -185,16 +185,7 @@ class IzyTV(object):
                 response,
             )
         )
-        STATUS = {
-            4: "Transaction validée",
-            1: "En attente de paiement",
-            2: "En attente de paiement",
-            3: "Transaction annulée",
-        }
         rstatus = response['status']
-        data['status'] = STATUS[rstatus]
-        data['info'] = STATUS[rstatus]
-
         if rstatus == 'SUCCESS':
             params = {
                 'session': '',
@@ -236,7 +227,7 @@ class IzyTV(object):
                         "info": "Activation annulée",
                     }
                 )
-        elif rstatus in ['EXPIRED','FAILED','NOT FOUND']:
+        elif rstatus in ['EXPIRED', 'FAILED', 'NOT FOUND']:
             self.update_Redis(
                 transId,
                 {
@@ -244,7 +235,6 @@ class IzyTV(object):
                 }
             )
 
-
     def update_Redis(self, redis_key, dict):
         """
         Updates the required fields in Redis from the given dictionnary.
