@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-import datetime
+from datetime import datetime
 import requests
 import logging
-from .consts import CONFIG, LOGS, ORANGE_MONEY, REDIS_DB, IzyTV, TODAY_STR
+from .consts import CONFIG, LOGS, ORANGE_MONEY, REDIS_DB, IzyTV
 
 
 class OrangeMoney(object):
@@ -133,7 +133,7 @@ class OrangeMoney(object):
 
     def writeToRedis(self, data, jresponse):
         """Writes the initial transaction inside Redis for asynchronous status checks. """
-        today = TODAY_STR
+        today = datetime.today().strftime("%Y-%m-%d %H:%M:%S")
         re_data = {
             "TransactionDate": today,
             "amount": data["amount"],
